| rmf_create_lvda | R Documentation |
RMODFLOW lvda objectrmf_create_lvda creates an RMODFLOW lvda object.
rmf_create_lvda(parameters, dis)
parameters |
either a single |
dis |
|
All parameters should have a layer attribute and their partyp attribute set to 'LVDA'. The LVDA package can only be used in conjunction with the HUF package. Note that the parameters are defined on the numerical grid, not the HUF grid
a RMODFLOW lvda object
rmf_read_lvda, rmf_write_lvda and http://water.usgs.gov/nrp/gwsoftware/modflow2000/MFDOC/index.html?lvda.htm
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.